==> img0ch-2.1.0.tar.bz2: img0ch/_template/default/read.cs <==
<html>
<head>
<!--nobanner-->
<title><?cs var:Subject ?></title>
<meta http-equiv="Content-Type" content="text/html; charset=Shift_JIS">
<meta http-equiv="Content-Script-Type" content="text/javascript">
<meta http-equiv="Content-Style-Type" content="text/css">
<meta name="VERSION" content="<?cs var:html_escape(VERSION) ?>">
<!--meta.txto͕-->
<?cs var:META ?>
<script type="text/javascript" src="<?cs var:StaticURI ?>/js/jquery.js?v=<?cs var:html_escape(SecuredVersion) ?>"></script>
<script type="text/javascript" src="<?cs var:StaticURI ?>/js/jquery/cookie.js?v=<?cs var:html_escape(SecuredVersion) ?>"></script>
<script type="text/javascript">
//<!--
$(function () {
    $("//input[@name='FROM']").val($.cookie("NAME"));
    $("//input[@name='mail']").val($.cookie("MAIL"));
    $("form").submit(function () {
        var option = { "expires": 30, "path": "<?cs var:BBS_COOKIE_PATH ?>" };
        $.cookie( "NAME", $("//input[@name='FROM']").val(), option );
        $.cookie( "MAIL", $("//input[@name='mail']").val(), option );
        $("//input[@type='submit']").attr({ "disabled": true });
        return true;
    });
});
//-->
</script>
<style type="text/css">
<!--
.clear { clear: both; }
.icon-align { vertical-align: top; }
.image { border: none; float: left; }
-->
</style>
</head>
<body bgcolor="<?cs var:BBS_THREAD_COLOR ?>" text="<?cs var:BBS_TEXT_COLOR ?>" link="<?cs var:BBS_LINK_COLOR ?>" alink="<?cs var:BBS_ALINK_COLOR ?>" vlink="<?cs var:BBS_VLINK_COLOR ?>">

<!--L\(Rg)-->
<?cs if:Banner ?><table border="1" cellspacing="7" cellpadding="3" width="100%" bgcolor="#ccffcc" align="center"><?cs var:Banner ?></table><hr><?cs /if ?>

<!--߂̃No͕-->
<a href="<?cs var:BBSURI ?>/">fɖ߂遡</a>
<!--֘Ay[W̃No͕(trackbackW[L̏ꍇ:Rĝ)-->
<?cs if:ModuleTRACKBACK ?>
<a href="<?cs var:TrackBack ?>">֘Ay[W</a>
<?cs /if ?>

<a href="<?cs var:ReadCGIURI ?>/">S</a>
<a href="<?cs var:ReadCGIURI ?>/1-100">1-</a>
<!--XɉăNo͂-->
<?cs each:item = LinkStack ?><a href="<?cs var:ReadCGIURI ?>/<?cs var:item.start ?>-<?cs var:item.end ?>"><?cs var:item.start ?>-</a>
<?cs /each ?>

<a href="<?cs var:ReadCGIURI ?>/l50">ŐV50</a><br><br>

<!--Xɂď݂oȂȂ邱Ƃ\o͂-->
<?cs if:r100 ?>
<table border=0><tr><td bgcolor=red><br><font color=white>
X1000𒴂Ă܂BcOȂS͕\܂B
</font><br></td></tr></table>
<?cs elif:r95 ?>
<table border=0><tr><td bgcolor=red><br><font color=white>
X950𒴂Ă܂B1000𒴂ƕ\łȂȂB
</font><br></td></tr></table>
<?cs elif:r90 ?>
<table border="0"><tr><td bgcolor="yellow"><br><font color="black">
X900𒴂Ă܂B1000𒴂ƕ\łȂȂB
</font><br></td></tr></table>
<?cs /if ?> <!-- NAME="90" -->

<dl>
<!--Xbh̃^Cgo͕-->
<font color="<?cs var:BBS_SUBJECT_COLOR ?>" size="+1"> <?cs var:Subject ?></font><br><br>

<!--Xo͕-->
<?cs each:item = Thread><dt><?cs var:item.resno ?>OF<b><?cs if:item.mail ?><a href="mailto:<?cs var:item.mail ?>"><?cs var:item.name ?></a><?cs else ?><font color="<?cs var:BBS_NAME_COLOR ?>"><?cs var:item.name ?></font><?cs /if ?></b>F<?cs var:item.date ?></dt><dd><?cs var:item.text ?><br><br></dd>
<?cs /each ?>
</dl>

<!--dat̑傫\-->
<font color=red face="Arial"><b><?cs var:DatKByteSize ?>KB</b></font>
<hr><center><a href="<?cs var:ReadCGIURI ?>/l<?cs var:ResCount ?>-">VX̕\</a></center><hr>
<a href="<?cs var:BBSURI ?>/">fɖ߂</a>

<!--֘Ay[W̃No͕(trackbackW[L̏ꍇ:Rĝ)-->
<?cs if:ModuleTRACKBACK ?>
<a href="<?cs var:TrackBack ?>">֘Ay[W</a>
<?cs /if ?>

<!--߂̃No͕-->
<a href="<?cs var:ReadCGIURI ?>/">S</a>
<a href="<?cs var:ReadCGIURI ?>/<?cs var:PrevStart ?>-<?cs var:PrevEnd ?>">O100</a>
<a href="<?cs var:ReadCGIURI ?>/<?cs var:NextStart ?>-<?cs var:NextEnd ?>">100</a>
<a href="<?cs var:ReadCGIURI ?>/l50">ŐV50</a>
<br>

<!--tH[\(Xwȓłꍇ\)-->
<?cs if:!r100 ?>

<form method="POST" action="<?cs var:CGIURI ?>/bbs.cgi" enctype="multipart/form-data">
<input type="hidden" name="bbs" value="<?cs var:BBS ?>">
<input type="hidden" name="key" value="<?cs var:KEY ?>">
<input type="hidden" name="time" value="<?cs var:TimeStamp ?>">
<input type="submit" value="">
OF<input type=text id="FROM" name="FROM" value="" size="19">
E-mail<font size=1>iȗj</font>F<input type=text id="mail" name="mail" value="" size="19"><br>
<?cs if:UploadableFromRes ?>摜F<input type="file" name="file" size="82"><br><?cs /if ?>
<textarea rows="5" cols="70" wrap="off" id="MESSAGE" name="MESSAGE"></textarea><br>
<small><?cs var:html_escape(VERSION) ?></small>
</form>
<?cs else ?>
<small><?cs var:html_escape(VERSION) ?></small>
<?cs /if ?>

</body>
</html>

==> img0ch-2.1.2.tar.bz2: img0ch/_template/default/read.cs <==
<html>
<head>
<!--nobanner-->
<title><?cs var:Subject ?></title>
<meta http-equiv="Content-Type" content="text/html; charset=Shift_JIS">
<meta http-equiv="Content-Script-Type" content="text/javascript">
<meta http-equiv="Content-Style-Type" content="text/css">
<meta name="VERSION" content="<?cs var:html_escape(VERSION) ?>">
<script type="text/javascript" src="<?cs var:StaticURI ?>/js/jquery.js?v=<?cs var:html_escape(SecuredVersion) ?>"></script>
<script type="text/javascript" src="<?cs var:StaticURI ?>/js/jquery/cookie.js?v=<?cs var:html_escape(SecuredVersion) ?>"></script>
<script type="text/javascript">
//<!--
jQuery(function () {
    jQuery("//input[@name='FROM']").val(jQuery.cookie("NAME"));
    jQuery("//input[@name='mail']").val(jQuery.cookie("MAIL"));
    jQuery("form").submit(function () {
        var option = { "expires": 30, "path": "<?cs var:BBS_COOKIE_PATH ?>" };
        jQuery.cookie( "NAME", jQuery( "input[@name='FROM']", this ).val(), option );
        jQuery.cookie( "MAIL", jQuery( "input[@name='mail']", this ).val(), option );
        jQuery("//input[@type='submit']").attr({ "disabled": true });
        return true;
    });
});
//-->
</script>
<style type="text/css">
<!--
.clear { clear: both; }
.icon-align { vertical-align: top; }
.image { border: none; float: left; margin-right: 4px; margin-bottom: 1px; }
-->
</style>
<!--meta.txto͕-->
<?cs var:META ?>
</head>
<body bgcolor="<?cs var:BBS_THREAD_COLOR ?>" text="<?cs var:BBS_TEXT_COLOR ?>" link="<?cs var:BBS_LINK_COLOR ?>" alink="<?cs var:BBS_ALINK_COLOR ?>" vlink="<?cs var:BBS_VLINK_COLOR ?>">

<!--L\(Rg)-->
<?cs if:Banner ?><table border="1" cellspacing="7" cellpadding="3" width="100%" bgcolor="#ccffcc" align="center"><?cs var:Banner ?></table><hr><?cs /if ?>

<!--߂̃No͕-->
<a href="<?cs var:BBSURI ?>/">fɖ߂遡</a>
<!--֘Ay[W̃No͕(trackbackW[L̏ꍇ:Rĝ)-->
<?cs if:ModuleTRACKBACK ?>
<a href="<?cs var:TrackBack ?>">֘Ay[W</a>
<?cs /if ?>

<a href="<?cs var:ReadCGIURI ?>/">S</a>
<a href="<?cs var:ReadCGIURI ?>/1-100">1-</a>
<!--XɉăNo͂-->
<?cs each:item = LinkStack ?><a href="<?cs var:ReadCGIURI ?>/<?cs var:item.start ?>-<?cs var:item.end ?>"><?cs var:item.start ?>-</a>
<?cs /each ?>

<a href="<?cs var:ReadCGIURI ?>/l50">ŐV50</a><br><br>

<!--Xɂď݂oȂȂ邱Ƃ\o͂-->
<?cs if:r100 ?>
<table border=0><tr><td bgcolor=red><br><font color=white>
X1000𒴂Ă܂BcOȂS͕\܂B
</font><br></td></tr></table>
<?cs elif:r95 ?>
<table border=0><tr><td bgcolor=red><br><font color=white>
X950𒴂Ă܂B1000𒴂ƕ\łȂȂB
</font><br></td></tr></table>
<?cs elif:r90 ?>
<table border="0"><tr><td bgcolor="yellow"><br><font color="black">
X900𒴂Ă܂B1000𒴂ƕ\łȂȂB
</font><br></td></tr></table>
<?cs /if ?> <!-- NAME="90" -->

<dl>
<!--Xbh̃^Cgo͕-->
<font color="<?cs var:BBS_SUBJECT_COLOR ?>" size="+1"> <?cs var:Subject ?></font><br><br>

<!--Xo͕-->
<?cs each:item = Thread><dt><?cs var:item.resno ?>OF<b><?cs if:item.mail ?><a href="mailto:<?cs var:item.mail ?>"><?cs var:item.name ?></a><?cs else ?><font color="<?cs var:BBS_NAME_COLOR ?>"><?cs var:item.name ?></font><?cs /if ?></b>F<?cs var:item.date ?></dt><dd><?cs var:item.text ?><br><br></dd>
<?cs /each ?>
</dl>

<!--dat̑傫\-->
<font color=red face="Arial"><b><?cs var:DatKByteSize ?>KB</b></font>
<hr><center><a href="<?cs var:ReadCGIURI ?>/<?cs var:ResCount ?>-n">VX̕\</a></center><hr>
<a href="<?cs var:BBSURI ?>/">fɖ߂</a>

<!--߂̃No͕-->
<a href="<?cs var:ReadCGIURI ?>/">S</a>
<a href="<?cs var:ReadCGIURI ?>/<?cs var:PrevStart ?>-<?cs var:PrevEnd ?>">O100</a>
<a href="<?cs var:ReadCGIURI ?>/<?cs var:NextStart ?>-<?cs var:NextEnd ?>">100</a>
<a href="<?cs var:ReadCGIURI ?>/l50">ŐV50</a>
<br>

<!--tH[\(Xwȓłꍇ\)-->
<?cs if:!r100 ?>

<form method="POST" action="<?cs var:CGIURI ?>/bbs.cgi" enctype="multipart/form-data">
<input type="hidden" name="bbs" value="<?cs var:BBS ?>">
<input type="hidden" name="key" value="<?cs var:KEY ?>">
<input type="hidden" name="time" value="<?cs var:TimeStamp ?>">
<input type="submit" value="">
OF<input type=text id="FROM" name="FROM" value="" size="19">
E-mail<font size=1>iȗj</font>F<input type=text id="mail" name="mail" value="" size="19"><br>
<?cs if:UploadableFromRes ?>摜F<input type="file" name="file" size="82"><br><?cs /if ?>
<textarea rows="5" cols="70" wrap="off" id="MESSAGE" name="MESSAGE"></textarea><br>
<small><?cs var:html_escape(VERSION) ?></small>
</form>
<?cs else ?>
<small><?cs var:html_escape(VERSION) ?></small>
<?cs /if ?>

</body>
</html>
